!function(e){var o={};function s(n){if(o[n])return o[n].exports;var t=o[n]={i:n,l:!1,exports:{}};return e[n].call(t.exports,t,t.exports,s),t.l=!0,t.exports}s.m=e,s.c=o,s.d=function(e,o,n){s.o(e,o)||Object.defineProperty(e,o,{enumerable:!0,get:n})},s.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},s.t=function(e,o){if(1&o&&(e=s(e)),8&o)return e;if(4&o&&"object"==typeof e&&e&&e.__esModule)return e;var n=Object.create(null);if(s.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:e}),2&o&&"string"!=typeof e)for(var t in e)s.d(n,t,function(o){return e[o]}.bind(null,t));return n},s.n=function(e){var o=e&&e.__esModule?function(){return e.default}:function(){return e};return s.d(o,"a",o),o},s.o=function(e,o){return Object.prototype.hasOwnProperty.call(e,o)},s.p="",s(s.s=0)}([function(e,o){let s,n=new Promise(e=>s=e);new BroadcastChannel("serviceWorker").onmessage=(async e=>{if(e.data&&"addToCache"===e.data.type){(await n).addAll(e.data.urls)}}),oninstall=(e=>{e&&e.waitUntil(caches.open("ntp-cache-3.0.2.929").then(e=>(s(e),e.addAll([]).catch(()=>{console.warn("Failed to add some resources.")}))).then(()=>skipWaiting()))}),onactivate=(e=>{e&&e.waitUntil(caches.keys().then(e=>Promise.all(e.map(e=>{if("ntp-cache-3.0.2.929"!==e)return caches.delete(e)}))))}),onfetch=(e=>{e&&e.respondWith(caches.match(e.request).then(o=>{if(o)return o;const s=e.request.clone();return fetch(s).then(o=>{if(!o||200!==o.status||"basic"!==o.type)return o.clone();const s=o.clone();return"GET"===e.request.method&&caches.open("ntp-cache-3.0.2.929").then(o=>o.put(e.request,s)),o})}))})}]);
//# sourceMappingURL=service_worker.js.map